summaryrefslogtreecommitdiff
path: root/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
diff options
context:
space:
mode:
authorPaul Duffin <paulduffin@google.com>2017-02-16 11:11:10 +0000
committerPaul Duffin <paulduffin@google.com>2017-02-16 11:11:10 +0000
commit747cc2ad6a92424a7e64de5a4f325ab7180df6d2 (patch)
tree848b861a708a4f665f8c5fa91752afca38242905 /libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
parent17f4fb05d4103f3ea554a0285b451b288afb939f (diff)
downloadlibphonenumber-747cc2ad6a92424a7e64de5a4f325ab7180df6d2.tar.gz
Upgrade to 8.3.0
Created using ./update-from-external.sh 7.7.5 m -j32 droid adb reboot bootloader fastboot flashall -w m -j32 cts cts-tradefed run cts -m CtsTelephonyTestCases -t android.telephony.cts.PhoneNumberUtilsTest m -j32 libphonenumber-test vogar --timeout 0 \ --classpath out/target/common/obj/JAVA_LIBRARIES/libphonenumber-test_intermediates/classes.jack \ com.google.i18n.phonenumbers Bug: 33563982 Test: As described above Change-Id: I74162ccd9874e035a5422da9abe561a6b20a67c9
Diffstat (limited to 'libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java')
-rw-r--r--libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java b/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
index c07a1739..dbf0f354 100644
--- a/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
+++ b/libphonenumber/src/com/google/i18n/phonenumbers/AlternateFormatsCountryCodeSet.java
@@ -26,9 +26,9 @@ import java.util.Set;
public class AlternateFormatsCountryCodeSet {
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
// The capacity is set to 57 as there are 43 different entries,
// and this offers a load factor of roughly 0.75.
- Set<Integer> countryCodeSet = new HashSet<Integer>(57);
+ Set<Integer> countryCodeSet = new HashSet<Integer>(58);
countryCodeSet.add(7);
countryCodeSet.add(27);
@@ -39,6 +39,7 @@ public class AlternateFormatsCountryCodeSet {
countryCodeSet.add(43);
countryCodeSet.add(44);
countryCodeSet.add(49);
+ countryCodeSet.add(52);
countryCodeSet.add(54);
countryCodeSet.add(55);
countryCodeSet.add(58);
@@ -26,9 +26,9 @@ import java.util.Set;
// A set of all country codes for which data is available.
static Set<Integer> getCountryCodeSet() {
- // The capacity is set to 57 as there are 43 different entries,
+ // The capacity is set to 58 as there are 44 different entries,
// and this offers a load factor of roughly 0.75.